Changelog
=========


2.0.0 (2021-05-19)
------------------

- Plone 5.2 compatibility
  [laulaz]

- Drop support for Plone 4, Plone 5.0 and Plone 5.1
  [laulaz]


1.2.0 (2020-09-06)
------------------

- Python 3.8 compatibility.
  [tisto]

- Use Dexterity names to avoid nasty interface lookup errors.
  [tisto]


1.1.0 (2019-04-15)
------------------

- Add French translation
  [laulaz]


1.0.0 (2019-02-23)
------------------

- Add missing German translations.
  [rodfersou]

- Fix headline styles.
  [rodfersou]


1.0.0a11 (2019-02-13)
---------------------

- Remove multilingual behavior.
  [rodfersou]


1.0.0a10 (2019-02-13)
---------------------

- Add extra standard behaviors.
  [rodfersou]


1.0.0a9 (2019-02-12)
--------------------

- Fix translations.
  [timo]


1.0.0a8 (2019-02-12)
--------------------

- Changed styles to match Products.Faq implementation.
  [rodfersou]

1.0.0a7 (2019-02-11)
--------------------

- Use icons from old Products.Faq package.
  [rodfersou]


1.0.0a6 (2019-02-05)
--------------------

- Add sprite for plus and minus icons for Plone 4.3.x.
  [rodfersou]


1.0.0a5 (2019-01-22)
--------------------

- Fix question link to expand item instead of navigate to question item.
  [rodfersou]

- Add content type icons for Plone 4.3.
  [rodfersou]


1.0.0a4 (2019-01-11)
--------------------

- Fix MANIFEST.in to include zcml files.
  This fixes https://github.com/collective/collective.faq/issues/3.
  [timo]


1.0.0a3 (2019-01-07)
--------------------

- Fix README RST style.
  [timo]


1.0.0a2 (2019-01-07)
--------------------

- Add FAQ content type to displayed_types (which show up in the navigation).
  [rodfersou]


1.0.0a1 (2019-01-04)
--------------------

- Initial release.
  [kitconcept]
